==> yellowdog_sdk-3.3.3-py3-none-any.whl: yellowdog_client/images/images_client.py <==
from abc import ABC, abstractmethod
from typing import List

from .page import Page
from .pageable import Pageable
from yellowdog_client.common import Closeable
from yellowdog_client.model import MachineImage, MachineImageFamily, MachineImageFamilySearch, MachineImageFamilySummary, MachineImageGroup


class ImagesClient(ABC, Closeable):

    @abstractmethod
    def add_image_family(self, family: MachineImageFamily) -> MachineImageFamily:
        pass

    @abstractmethod
    def add_image_group(self, family: MachineImageFamily, group: MachineImageGroup) -> MachineImageGroup:
        pass

    @abstractmethod
    def add_image(self, group: MachineImageGroup, image: MachineImage) -> MachineImage:
        pass

    @abstractmethod
    def update_image_family(self, family: MachineImageFamily) -> MachineImageFamily:
        pass

    @abstractmethod
    def update_image_group(self, group: MachineImageGroup) -> MachineImageGroup:
        pass

    @abstractmethod
    def update_image(self, image: MachineImage) -> MachineImage:
        pass

    @abstractmethod
    def delete_image_family(self, family: MachineImageFamily) -> None:
        pass

    @abstractmethod
    def delete_image_group(self, group: MachineImageGroup) -> None:
        pass

    @abstractmethod
    def delete_image(self, image: MachineImage) -> None:
        pass

    @abstractmethod
    def get_image_family_by_name(self, namespace: str, family_name: str) -> MachineImageFamily:
        pass

    @abstractmethod
    def get_image_family_by_id(self, family_id: str) -> MachineImageFamily:
        pass

    @abstractmethod
    def get_latest_image_group_by_family_name(self, namespace: str, family_name: str) -> MachineImageGroup:
        pass

    @abstractmethod
    def get_latest_image_group_by_family_id(self, family_id: str) -> MachineImageGroup:
        pass

    @abstractmethod
    def get_image_group_by_name(self, namespace: str, family_name: str, group_name: str) -> MachineImageGroup:
        pass

    @abstractmethod
    def get_image_group_by_id(self, group_id: str) -> MachineImageGroup:
        pass

    @abstractmethod
    def get_image_by_id(self, image_id: str) -> MachineImage:
        pass

    @abstractmethod
    def get_all_image_families(self) -> List[MachineImageFamilySummary]:
        pass

    @abstractmethod
    def search_image_families(self, search: MachineImageFamilySearch) -> List[MachineImageFamilySummary]:
        pass

    @abstractmethod
    def search_image_families_paged(self, search: MachineImageFamilySearch, pageable: Pageable) -> Page[MachineImageFamilySummary]:
        pass

==> yellowdog_sdk-3.5.1-py3-none-any.whl: yellowdog_client/images/images_client.py <==
from abc import ABC, abstractmethod
from typing import List

from .page import Page
from .pageable import Pageable
from yellowdog_client.common import Closeable
from yellowdog_client.model import MachineImage, MachineImageFamily, MachineImageFamilySearch, MachineImageFamilySummary, MachineImageGroup


class ImagesClient(ABC, Closeable):

    @abstractmethod
    def add_image_family(self, family: MachineImageFamily) -> MachineImageFamily:
        pass

    @abstractmethod
    def add_image_group(self, family: MachineImageFamily, group: MachineImageGroup) -> MachineImageGroup:
        pass

    @abstractmethod
    def add_image(self, group: MachineImageGroup, image: MachineImage) -> MachineImage:
        pass

    @abstractmethod
    def update_image_family(self, family: MachineImageFamily) -> MachineImageFamily:
        pass

    @abstractmethod
    def update_image_group(self, group: MachineImageGroup) -> MachineImageGroup:
        pass

    @abstractmethod
    def update_image(self, image: MachineImage) -> MachineImage:
        pass

    @abstractmethod
    def delete_image_family(self, family: MachineImageFamily) -> None:
        pass

    @abstractmethod
    def delete_image_group(self, group: MachineImageGroup) -> None:
        pass

    @abstractmethod
    def delete_image(self, image: MachineImage) -> None:
        pass

    @abstractmethod
    def get_image_family_by_id(self, family_id: str) -> MachineImageFamily:
        pass

    @abstractmethod
    def get_image_family_by_name(self, namespace: str, family_name: str) -> MachineImageFamily:
        pass

    @abstractmethod
    def get_latest_image_group_by_family_id(self, family_id: str) -> MachineImageGroup:
        pass

    @abstractmethod
    def get_latest_image_group_by_family_name(self, namespace: str, family_name: str) -> MachineImageGroup:
        pass

    @abstractmethod
    def get_image_group_by_id(self, group_id: str) -> MachineImageGroup:
        pass

    @abstractmethod
    def get_image_group_by_name(self, namespace: str, family_name: str, group_name: str) -> MachineImageGroup:
        pass

    @abstractmethod
    def get_image(self, image_id: str) -> MachineImage:
        pass

    @abstractmethod
    def get_all_image_families(self) -> List[MachineImageFamilySummary]:
        pass

    @abstractmethod
    def search_image_families(self, search: MachineImageFamilySearch) -> List[MachineImageFamilySummary]:
        pass

    @abstractmethod
    def search_image_families_paged(self, search: MachineImageFamilySearch, pageable: Pageable) -> Page[MachineImageFamilySummary]:
        pass
